@@ -1,10 +1,8 @@
 use bevy::prelude::*;
 use notation_bevy_utils::prelude::ShapeOp;
 
-use std::sync::Arc;
-
 use crate::{prelude::NotationTheme, settings::notation_settings::NotationSettings, tone::{tone_line::{ToneLineData, ToneLineValue}, tone_mode::ToneMode}};
-use notation_model::{prelude::{TabBar, Note, Semitones}, bar_lane::BarLane};
+use notation_model::{prelude::{Semitones}, bar_lane::BarLane};
 
 #[derive(Debug, Default, Component)]
 pub struct MelodyGrid();
@@ -23,14 +21,12 @@ impl MelodyGrid {
             let key = bar.tab_meta().key;
             let root = scale.get_syllables()[0];
             for semitones in theme.sizes.melody.lowest.0 ..= theme.sizes.melody.highest.0 {
-                let note = Note::from(Semitones(semitones));
-                let syllable_note = scale.calc_syllable_note(&key, &note);
-                if root == syllable_note.syllable {
+                let note = scale.calc_note_from_semitones(&key, Semitones(semitones));
+                if root == note.syllable {
                     let data = ToneLineData::new(lane, ToneLineValue {
                         mode: ToneMode::Melody,
                         is_root: false,
                         note,
-                        syllable_note,
                         bar_size: 0.0,
                     });
                     data.create(commands, theme, entity);
